"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.parsePackagesResponses = exports.parsePackagesResponse = exports.ComposerPackagesResponse = exports.ComposerReleaseArray = exports.ComposerRelease = void 0;
const zod_1 = require("zod");
const composer_1 = require("../../versioning/composer");
exports.ComposerRelease = zod_1.z.object({
    version: zod_1.z
        .string()
        .refine((v) => composer_1.api.isSingleVersion(v), 'Invalid version'),
    homepage: zod_1.z.string().nullable().catch(null),
    source: zod_1.z
        .object({
        url: zod_1.z.string(),
    })
        .transform((x) => x.url)
        .nullable()
        .catch(null),
    time: zod_1.z.string().nullable().catch(null),
});
exports.ComposerReleaseArray = zod_1.z
    .array(exports.ComposerRelease.nullable().catch(null))
    .transform((xs) => xs.filter((x) => x !== null));
exports.ComposerPackagesResponse = zod_1.z.object({
    packages: zod_1.z.record(zod_1.z.unknown()),
});
function parsePackagesResponse(packageName, packagesResponse) {
    const packagesResponseParsed = exports.ComposerPackagesResponse.safeParse(packagesResponse);
    if (!packagesResponseParsed.success) {
        return [];
    }
    const { packages } = packagesResponseParsed.data;
    const releaseArray = packages[packageName];
    const releaseArrayParsed = exports.ComposerReleaseArray.safeParse(releaseArray);
    if (!releaseArrayParsed.success) {
        return [];
    }
    return releaseArrayParsed.data;
}
exports.parsePackagesResponse = parsePackagesResponse;
function parsePackagesResponses(packageName, packagesResponses) {
    const releases = [];
    let maxVersion = null;
    let homepage = null;
    let sourceUrl = null;
    for (const packagesResponse of packagesResponses) {
        const releaseArray = parsePackagesResponse(packageName, packagesResponse);
        for (const composerRelease of releaseArray) {
            const version = composerRelease.version.replace(/^v/, '');
            const gitRef = composerRelease.version;
            const dep = { version, gitRef };
            if (composerRelease.time) {
                dep.releaseTimestamp = composerRelease.time;
            }
            releases.push(dep);
            if (!maxVersion || composer_1.api.isGreaterThan(version, maxVersion)) {
                maxVersion = version;
                homepage = composerRelease.homepage;
                sourceUrl = composerRelease.source;
            }
        }
    }
    if (releases.length === 0) {
        return null;
    }
    const result = { releases };
    if (homepage) {
        result.homepage = homepage;
    }
    if (sourceUrl) {
        result.sourceUrl = sourceUrl;
    }
    return result;
}
exports.parsePackagesResponses = parsePackagesResponses;
//# sourceMappingURL=schema.js.map